ClassSwitchError class
课堂自动切换错误。包装 _joinNewClass 过程中可能抛出的任何异常, 由 ClassSwitcher 根据 retryable 决定是否重试。
- Implemented types
Constructors
- ClassSwitchError({required int code, required String message, required bool retryable, Object? cause})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited