MembersInfoObs class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • MembersInfoObs
Implemented types

Constructors

MembersInfoObs()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isSelfOnline → Rx<bool>
final
isTeacherOnStage → Rx<bool>
老师是否在台上 - 仅老师stage变化时更新
final
joinClassTime → Rx<String>
final
listeners int
no setterinherited
memberCount int
no setter
memberIds → RxList<String>
final
membersInfo → RxMap<String, Member>
final
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onlineStudentCount → Rx<int>
final
onStageMembersInfo → RxMap<String, Member>
台上用户信息Map - 仅台上用户变化时更新
final
onStageUserIds → RxList<String>
台上用户ID列表 - 仅在台上用户变化时更新
final
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selfBoardPermission → Rx<int>
final
selfCameraPermission → Rx<int>
final
selfCameraState → Rx<int>
final
selfInfo Member?
no setter
selfIsAssistant bool
no setter
selfIsTeacher bool
no setter
selfMicPermission → Rx<int>
final
selfMicState → Rx<int>
final
selfScreenPermission → Rx<int>
final
selfScreenState → Rx<int>
final
selfStageState → Rx<int>
final
selfUserInfo → Rx<TCICSelfInfoModel>
final
teacherFloatingShown → Rx<bool>
final
teacherInfo → Rx<Member?>
老师信息 - 仅老师状态变化时更新
final
trtcViewScope → Rx<TRTCViewScopeEnum>
final

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
clearMembers() → void
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
getMemberInfo(String userId, int classId) Future<Member?>
getMemberInfoByUserId(String userId) Member?
getMembersInfoMap() Map<String, Member>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
inherited
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
removeMember(String userId, String reason) → void
移除指定成员(用于成员离开房间时)
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited
updateIsSelfOnline(bool isOnline, String reason) → dynamic
updateJoinClassTime(String time) → dynamic
updateMemberInfo(Member memberInfo, String reason) → dynamic
updateMembersInfo(Map<String, Member> infos, String reason) → dynamic
updateOnlineStudentCount(int count) → dynamic
updateSelfConfig(Member memberInfo) → void
updateSelfMemberInfoByAction(MemberActionType actionType, int state) → dynamic
updateSelfUserInfo(TCICSelfInfoModel userInfo) → dynamic
updateTeacherFloatingShown(bool shown) → dynamic
updateTRTCViewScope(TRTCViewScopeEnum scope) → dynamic

Operators

operator ==(Object other) bool
The equality operator.
inherited