ToolsController class

Constructors

ToolsController()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

answerQuestion(String questionId, int answer) → Future<AnswerQuestionResult?>
closeQuestion({required String questionId}) → Future
createQuestion({required int classId, required int optionNumber, required int correctAnswer, required int type, required int duration, required String questionContent}) → Future<CreateQuestionResult?>
getMyQuestions({required int classId}) → Future<QuestionResult?>
getQuestions({required int classId}) → Future<QuestionResult?>
getQuestionStats({required String questionId}) → Future<QuestionStatics?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stopQuestion({required String questionId}) → Future
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited