PlayBackController class

Constructors

PlayBackController()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cacheMetaDataByClassId(String classId, String token, CacheMetadataListener listener, {bool force = false, PlayBackEnvEnum env = PlayBackEnvEnum.production}) Future<void>
拉取回放元数据并以 classId.json 保存到本地
clearAllCachedMetaData() Future<bool>
clearCachedMetaData(String classId) Future<bool>
downloadByUrl(String url, {String? savePath, void onReceiveProgress(int received, int total)?}) Future<String>
下载指定 URL 的文件到 savePath,返回本地路径
downloadMetaData(String classId, String token) Future<void>
根据本地 classId.json 下载视频和文档图片,将在线 URL 替换为本地路径
getCachedMetaData(String classId) Future<Map<String, dynamic>>
getCachedMetaDataStatus(String classId) Future<CacheStatusEnum>
根据本地缓存文件判定当前缓存状态。 若 success.json 存在,会进一步校验其中引用的白板视频、老师视频、课件图片是否均在本地存在, 任一文件缺失则删除 success.json 并返回未缓存。
getCacheMetadataListener(String classId) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

cacheMetadataListeners Map<String, CacheMetadataListener>
getter/setter pair