FloatingComponentStateEvent class

浮动组件状态变化事件

Constructors

FloatingComponentStateEvent({required LayoutPosition position, required ComponentType? componentType, required FloatingComponentState state, bool isAutoTriggered = false, DateTime? timestamp})

Properties

componentType ComponentType?
组件类型
final
hashCode int
The hash code for this object.
no setterinherited
isAutoTriggered bool
是否是自动触发(自动隐藏)
final
isCollapsed bool
no setter
isExpanded bool
no setter
position LayoutPosition
组件位置
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state FloatingComponentState
新状态
final
timestamp DateTime
时间戳
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited