AudioPlayerController class

Constructors

AudioPlayerController(BuildContext context)

Properties

audioPlayerFloating ↔ Floating?
getter/setter pair
classId ↔ int
getter/setter pair
context → BuildContext
final
curUserId ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAssistant ↔ bool
getter/setter pair
isTeacher ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showAudioPlayer() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → AudioPlayerController
no setter