ClockToolState class

Inheritance

Constructors

ClockToolState()

Properties

callback ↔ TCICCallback
getter/setter pairinherited
config ↔ TCICConfig
getter/setter pairinherited
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
controller ↔ TCICController
getter/setter pairinherited
currentSeconds ↔ int
getter/setter pair
currentStatus ↔ ClockStatus
getter/setter pair
eventbus ↔ TCICEventbus
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
iconController ↔ TCICIconController
getter/setter pairinherited
isAssistant ↔ bool
getter/setter pair
isInitBusiness ↔ bool
getter/setter pairinherited
isTeacher ↔ bool
getter/setter pair
minuteHigh ↔ int
getter/setter pair
minuteLow ↔ int
getter/setter pair
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondHigh ↔ int
getter/setter pair
secondLow ↔ int
getter/setter pair
startSeconds ↔ int
getter/setter pair
startTime ↔ int
getter/setter pair
stateDataController ↔ TCICStateDataObs
getter/setter pairinherited
timeCounts ↔ List<String>
getter/setter pair
timer ↔ Timer?
getter/setter pair
updateTime ↔ int
getter/setter pair
widget → ClockTool
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createButton(StringEnum text, dynamic onTap(), bool isOutline) → Widget
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant ClockTool oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
exit() → void
override
init() → void
override
initBusiness() → dynamic
inherited
initState() → void
Called when this object is inserted into the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChangeMinute(int high, int low) → void
onChangeSecond() → void
onContinue() → void
onCount() → void
onJoinClass() → void
onPause() → void
onRestart() → void
onStart() → void
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
resetData() → void
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
startTimer() → void
stopTask() → dynamic
stopTimer() → void
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
updateClock() → void
updateTask() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited