AnimationComponent class

动画组件 - 高阶组件,为子组件添加动画效果

Inheritance

Constructors

AnimationComponent({Key? key, required Widget child, required ComponentAnimationType animationType, AnimationController? controller, Duration duration = const Duration(milliseconds: 300), Duration delay = Duration.zero, Curve curve = Curves.easeInOut, bool autoStart = true, bool repeat = false, bool reverse = false, VoidCallback? onAnimationComplete, VoidCallback? onAnimationStart})
const

Properties

animationType → ComponentAnimationType
动画类型
final
autoStart → bool
是否自动开始动画
final
child → Widget
子组件
final
controller → AnimationController?
动画控制器
final
curve → Curve
动画曲线
final
delay → Duration
动画延迟时间
final
duration → Duration
动画持续时间
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onAnimationComplete → VoidCallback?
动画完成回调
final
onAnimationStart → VoidCallback?
动画开始回调
final
repeat → bool
是否重复动画
final
reverse → bool
是否反向重复
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<AnimationComponent>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited