build method

  1. @override
Widget build(
  1. BuildContext context
)
override

Describes the part of the user interface represented by this widget.

The framework calls this method when this widget is inserted into the tree in a given BuildContext and when the dependencies of this widget change (e.g., an InheritedWidget referenced by this widget changes). This method can potentially be called in every frame and should not have any side effects beyond building a widget.

The framework replaces the subtree below this widget with the widget returned by this method, either by updating the existing subtree or by removing the subtree and inflating a new subtree, depending on whether the widget returned by this method can update the root of the existing subtree, as determined by calling Widget.canUpdate.

Typically implementations return a newly created constellation of widgets that are configured with information from this widget's constructor and from the given BuildContext.

The given BuildContext contains information about the location in the tree at which this widget is being built. For example, the context provides the set of inherited widgets for this location in the tree. A given widget might be built with multiple different BuildContext arguments over time if the widget is moved around the tree or if the widget is inserted into the tree in multiple places at once.

The implementation of this method must only depend on:

If a widget's build method is to depend on anything else, use a StatefulWidget instead.

See also:

  • StatelessWidget, which contains the discussion on performance considerations.

Implementation

@override
Widget build(BuildContext context) {
  return Obx(() {
    final controller = TCICController.instance;
    final isPortrait =
        MediaQuery.of(context).orientation == Orientation.portrait;

    // 获取配置
    final showHandsupIcon = _headerComponentConfig?.enableHandsUp ?? true;
    final showMessageIcon = _headerComponentConfig?.enableMessage ?? true;
    final showMembersIcon = _headerComponentConfig?.enableMemberList ?? true;
    final showCourseIcon = _headerComponentConfig?.enableCoureseware ?? true;
    final showShareIcon = _headerComponentConfig?.enableScreenShare ?? true;
    final showSettingIcon = _headerComponentConfig?.enableSetting ?? true;
    final showMicToggleButton =
        _headerComponentConfig?.enableMicToggle ?? true;
    final showCameraToggleButton =
        _headerComponentConfig?.enableCameraToggle ?? true;

    final isVertical = layoutOrientation == HeaderLayoutOrientation.vertical;

    final membersInfoObs = controller.getMembersInfoObs();
    // 判断自己是否已上台
    final selfMemberInfo = membersInfoObs.getMemberInfoByUserId(
      controller.getConfig().userId,
    );
    final isSelfOnStage = selfMemberInfo?.stage == 1;

    final handupButtonKeepEnabled =
        controller.getConfig().basicConfig?.handupButtonKeepEnabled ?? false;
    final role = controller.getRole();

    // 构建按钮列表
    final buttons = <Widget>[
      // 已上台:显示麦克风和摄像头控制,未上台:显示举手按钮
      if (isSelfOnStage) ...[
        if (showMicToggleButton) MicToggle(),
        if (TcicScreen.isDeskTop() && showMicToggleButton) SizedBox(width: 5),
        if (showCameraToggleButton) CameraToggle(),
        if (showCameraToggleButton || showMicToggleButton)
          DividerPure(isVertical: isVertical),
      ] else ...[
        if (showHandsupIcon && _showHandsupIcon(controller)) HandsUp(),
        if (showHandsupIcon && _showHandsupIcon(controller))
          DividerPure(isVertical: isVertical),
      ],
      // 已上台且配置了 handupButtonKeepEnabled,在 MessageToggle 前显示 HandsUp
      if (isSelfOnStage && handupButtonKeepEnabled && showHandsupIcon && role != RoleEnum.teacher)
        HandsUp(),
      if (showMessageIcon && !isPortrait) MessageToggle(),
      if (showMembersIcon && _showMembersIcon(controller)) MembersToggle(),
      if (showCourseIcon && _showCourseIcon(controller)) CourseToggle(),
      if (showShareIcon && _showShareIcon(controller)) ScreenShareToggle(),
      if (showSettingIcon) SettingToggle(),
      if (_showToolsIcon(controller)) ToolsPannel(),
    ];
    TCICLog.info(
      "HeaderActionButtons buttons: ${buttons.length} isSelfOnStage: $isSelfOnStage selfMemberInfo: ${selfMemberInfo?.toJson()}",
      actionModule: ActionModule.headerActionButtons.name,
      actionName: ActionName.headerActionButtons.name,
    );
    return HeaderActionButtonsPure(
        isPortrait: isPortrait,
        layoutOrientation: layoutOrientation,
        buttons: buttons,
      );
  });
}