TCICChatSession class

Inheritance

Constructors

TCICChatSession({TCICController? controller, Member? initialReceiver})

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
keyboardDetectionController → KeyboardDetectionController
final
receiverMember Member
no setter
repliedMessage → V2TimMessage?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
closeReply({required int silenceMode, required bool isTeacherOrAssistant}) Future<void>
dispose() → void
Discards any resources used by the object.
override
initialize() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
replyToMessage({required V2TimMessage message, required int silenceMode, required bool isTeacherOrAssistant}) Future<void>
selectReceiver(Member member) → void
syncSilenceMode({required int silenceMode, required bool isTeacherOrAssistant}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited