PlayBackComponent class

Inheritance

Constructors

PlayBackComponent({Key? key, required PlaybackConfig config, required TCICController controller, VoidCallback? onClose, VoidCallback? onPlaybackClosedNotify, void onPlaybackError(String error)?, PlaybackEventNotifier? onPlaybackEvent, MasterClockChangeNotifier? onMasterClockChange, MasterTimelineScrubbedNotifier? onMasterTimelineScrubbed, void onPlaybackPageReady(int totalDurationSec)?, PlaybackCustomUIEventNotifier? onCustomUIEvent, Widget? customAppBarActionWidget, Widget? customFloatingActionWidget})
const

Properties

config PlaybackConfig
final
controller TCICController
final
customAppBarActionWidget Widget?
Native 下发 JSON 解析后的 AppBar 自定义区域 Widget
final
customFloatingActionWidget Widget?
Native 下发 JSON 解析后的右下角自定义区域 Widget
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onClose VoidCallback?
由外部注入的关闭回调(如 Native 打开的回放页),点击返回时优先调用,避免单路由下 Navigator.pop 导致白屏
final
onCustomUIEvent PlaybackCustomUIEventNotifier?
回放页自定义 UI 点击事件回调(AppBar action / 右下悬浮按钮)
final
onMasterClockChange MasterClockChangeNotifier?
主时钟变更时回调(供白板信令重放、进度条、上报等使用)
final
onMasterTimelineScrubbed MasterTimelineScrubbedNotifier?
主时间轴滑块松手后回调(在线会先请求最新快照再触发;可与 onMasterClockChange 配合做上报)
final
onPlaybackClosedNotify VoidCallback?
页面 dispose 时通知 Native 关闭(仅发回调,不 setState)。未传时由内部改为 DevicePlatform.notifyPlayBackPageClosed,保证全路径只触发一次
final
onPlaybackError → void Function(String error)?
回放错误时通知 Native
final
onPlaybackEvent PlaybackEventNotifier?
回放播放事件时通知 Native(play/pause/seek/timeupdate/ratechange/ended 等)
final
onPlaybackPageReady → void Function(int totalDurationSec)?
回放页数据就绪回调(元数据加载完成后触发一次),参数为回放总时长(秒)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<PlayBackComponent>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited