UnrealBgItem class

Constructors

UnrealBgItem({required String key, required String bgUrl, required UnrealBgType bgType, StringEnum? bgNameEnum, String? customName, String? assetPackage, bool isCustom = false})
const

Properties

assetPackage String?
final
bgNameEnum StringEnum?
final
bgType UnrealBgType
final
bgUrl String
final
customName String?
final
displayName String
no setter
hashCode int
The hash code for this object.
no setterinherited
isCustom bool
final
key String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited