TCICEventbus class

Constructors

TCICEventbus()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cacheClear() → void
clear() → void
fire(dynamic event, [bool isCache = true]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
off(StreamSubscription subscription) → void
on<T>(OnEventBusData<T> onData, [List<Enum>? eventTypes]) StreamSubscription<T>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited