TCICLogImpl class
Web 端日志实现 - 仅做本地打印
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
debug(
dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace, bool isReport = true, required String actionModule, required String actionName}) → void -
error(
dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace, bool isReport = true, required String actionModule, required String actionName}) → void -
fatal(
dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace, bool isReport = true, required String actionModule, required String actionName}) → void -
info(
dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace, bool isReport = true, double? sampleRate = 1.0, required String actionModule, required String actionName}) → void -
isLogPathInitialized(
dynamic message) → bool -
report(
dynamic logParam) → void -
warn(
dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace, bool isReport = true, required String actionModule, required String actionName}) → void