UserHandUpInfo class

Inheritance

Constructors

UserHandUpInfo({required String userId, required String userName, required int handUpTimes, required int handUpTimestamp})

Properties

handUpTimes int
final
handUpTimestamp int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
final
userName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) UserHandUpInfo
override