GetMessageParams class abstract

Inheritance
Annotations
  • @freezed

Constructors

GetMessageParams({@JsonKey.new(name: 'class_id') required int classId, @JsonKey.new(name: 'user_id') required String userId})
factory
GetMessageParams.fromJson(Map<String, dynamic> json)
factory

Properties

classId → int
no setterinherited
copyWith → $GetMessageParamsCopyWith<GetMessageParams>
Create a copy of GetMessageParams with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this GetMessageParams to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited