CacheStatusEnum enum

Inheritance
Available extensions

Values

notCached → const CacheStatusEnum

未缓存

caching → const CacheStatusEnum

缓存中(当前进程内正在下载)

cachedSuccess → const CacheStatusEnum

缓存成功

cachedFailed → const CacheStatusEnum

缓存失败

cacheInterrupted → const CacheStatusEnum

下载未完成(如杀进程),本地仍保留元数据与已下文件,可再次调用 cache 重新下载

cachePaused → const CacheStatusEnum

用户主动暂停下载(调用 pauseDownloadCache),本地已下文件保留,可调用 resumeDownloadCache 续传

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CacheStatusEnum>
A constant List of the values in this enum, in order of their declaration.