PlaybackConfig class

Inheritance

Constructors

PlaybackConfig({required String token, required String classId, required String userId, bool offlineMode = false, PlayBackEnvEnum env = PlayBackEnvEnum.production})

Properties

classId String
final
env PlayBackEnvEnum
final
hashCode int
The hash code for this object.
no setterinherited
offlineMode bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
final
userId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) PlaybackConfig
override