PlayBackMessageModel class

Inheritance

Constructors

PlayBackMessageModel({required String content, required int offset, required int timestamp, required String userName})

Properties

content → String
final
hashCode → int
The hash code for this object.
no setterinherited
offset → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → int
final
userName → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → PlayBackMessageModel
override