PlayBackSignalData class

Inheritance

Constructors

PlayBackSignalData({required int offset, required int seq, required int timestamp, required String value})

Properties

hashCode int
The hash code for this object.
no setterinherited
offset int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seq int
final
timestamp int
final
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) PlayBackSignalData
override