CoursewarePrefetchUrl class

白板回放课件预热 URL 条目。

offsetMs 为该页在主时间轴上首次被切换展示的偏移(毫秒),用于滚动窗口模式按播放位置排序。

Constructors

CoursewarePrefetchUrl(int offsetMs, String url)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
offsetMs int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited