PlaybackScreenShareSegment class

Inheritance

Constructors

PlaybackScreenShareSegment({required String userId, required String videoUrl, required int startSec, required int durationSec})

Properties

durationSec int
final
endSec int
no setter
hashCode int
The hash code for this object.
no setterinherited
isValid bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startSec int
final
userId String
final
videoUrl String
final

Methods

contains(double masterSec) bool
innerSec(double masterSec) double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) PlaybackScreenShareSegment?
override