AnswerQuestionResult class abstract

Inheritance
Annotations
  • @freezed

Constructors

AnswerQuestionResult({@JsonKey.new(name: 'correct_answer') required int correctAnswer, @JsonKey.new(name: 'cost_time') required int costTime})
factory
AnswerQuestionResult.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $AnswerQuestionResultCopyWith<AnswerQuestionResult>
Create a copy of AnswerQuestionResult with the given fields replaced by the non-null parameter values.
no setterinherited
correctAnswer → int
no setterinherited
costTime → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this AnswerQuestionResult to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited