QuestionAnswer class abstract

Inheritance
Annotations
  • @freezed

Constructors

QuestionAnswer({@JsonKey.new(name: 'user_id') required String userId, required int answer, required int timestamp, @JsonKey.new(name: 'cost_time') required int costTime})
factory
QuestionAnswer.fromJson(Map<String, dynamic> json)
factory

Properties

answer → int
no setterinherited
copyWith → $QuestionAnswerCopyWith<QuestionAnswer>
Create a copy of QuestionAnswer with the given fields replaced by the non-null parameter values.
no setterinherited
costTime → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → int
no setterinherited
userId → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this QuestionAnswer to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited