QuestionInfo class abstract

Annotations
  • @freezed

Constructors

QuestionInfo({@JsonKey.new(name: 'question_id') @Default.new("") String questionId, @JsonKey.new(name: 'question_content') @Default.new("") String questionContent, @JsonKey.new(name: 'question_name') @Default.new("") String questionName, @JsonKey.new(name: 'start_time') @Default.new(0) int startTime, @JsonKey.new(name: 'state') @Default.new(0) int state, @JsonKey.new(name: 'ttl') @Default.new(0) int ttl, @JsonKey.new(name: 'type') @Default.new(1) int type, @JsonKey.new(name: 'duration') @Default.new(0) int duration, @JsonKey.new(name: 'correct_answer') @Default.new(0) int correctAnswer, @JsonKey.new(name: 'option_number') @Default.new(0) int optionNumber})
factory
QuestionInfo.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $QuestionInfoCopyWith<QuestionInfo>
Create a copy of QuestionInfo with the given fields replaced by the non-null parameter values.
no setterinherited
correctAnswer → int
no setterinherited
duration → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
optionNumber → int
no setterinherited
questionContent → String
no setterinherited
questionId → String
no setterinherited
questionName → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → int
no setterinherited
state → int
no setterinherited
ttl → int
no setterinherited
type → int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this QuestionInfo to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited