TCICConfig class

Inheritance

Constructors

TCICConfig({required String token, required String classId, required String userId, String? nativeSdkVersion, String? groupLiveCode, RoleEnum? role, TCICLangConfig? langConfig, TCICNameConfig? nameConfig, TCICCustomStrings? customStrings, TCICTextReplace? textReplace, TCICFontConfig? fontConfig, List<TCICComponentConfig>? componentConfig, bool? isLatestBackend = false, bool? isTestBackend = false, TCICBasicConfig? basicConfig, TCICBoardConfig? boardConfig, TCICLayoutConfig? layoutConfig, TCICWatermarkConfig? watermarkConfig, TCICToastConfig? toastConfig, TCICLogLevelEnum? logLevel, String? nextClassId, bool? classSwitchEnabled})

Properties

basicConfig TCICBasicConfig?
getter/setter pair
boardConfig TCICBoardConfig?
getter/setter pair
classId String
getter/setter pair
classSwitchEnabled bool?
课堂无感切换开关。null/true 表示启用;false 时即使有 nextClassId 也走原结束流程。
getter/setter pair
componentConfig List<TCICComponentConfig>?
getter/setter pair
customStrings TCICCustomStrings?
getter/setter pair
fontConfig TCICFontConfig?
getter/setter pair
groupLiveCode String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isLatestBackend bool?
getter/setter pair
isTestBackend bool?
getter/setter pair
langConfig TCICLangConfig?
getter/setter pair
layoutConfig TCICLayoutConfig?
getter/setter pair
logLevel TCICLogLevelEnum?
getter/setter pair
nameConfig TCICNameConfig?
getter/setter pair
nativeSdkVersion String?
getter/setter pair
nextClassId String?
下一节课堂 ID(课堂无感切换用)。 业务侧在 classEnd 之前设置;SDK 收到 classEnd 时如非空, 自动软销毁当前课堂资源并加入该课堂。为空表示走原有结束流程。
getter/setter pair
role RoleEnum?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textReplace TCICTextReplace?
getter/setter pair
toastConfig TCICToastConfig?
getter/setter pair
token String
getter/setter pair
userId String
getter/setter pair
watermarkConfig TCICWatermarkConfig?
getter/setter pair

Methods

destroy() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) TCICConfig
override