SetttingComponentConfig class

Inheritance

Constructors

SetttingComponentConfig({bool enableAudioSetting = true, bool enableVideoSetting = true, bool enableGeneralSetting = true, bool showMemberJoinExitInfo = true, bool showMemberHansupInfo = true, bool showBarrage = true, bool showOnlyTeacherMessage = false, bool showOtherSetting = true, List<TCICVirtualBackgroundImage>? virtualBackgroundImages})

Properties

enableAudioSetting bool
是否启用音频设置
getter/setter pair
enableGeneralSetting bool
是否启用通用设置
getter/setter pair
enableVideoSetting bool
是否启用视频设置
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBarrage bool
是否显示弹幕
getter/setter pair
showMemberHansupInfo bool
是否显示成员举手信息
getter/setter pair
showMemberJoinExitInfo bool
是否显示成员加入退出课堂信息
getter/setter pair
showOnlyTeacherMessage bool
是否仅显示老师消息
getter/setter pair
showOtherSetting bool
是否展示其他设置
getter/setter pair
virtualBackgroundImages List<TCICVirtualBackgroundImage>?
自定义虚拟背景图片列表
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) SetttingComponentConfig
override