WhiteboardComponentConfig class

Inheritance

Constructors

WhiteboardComponentConfig({bool? enableCreateBoard, bool? enableBoardList, bool? enableSwitchPage, Color? collapsedBackgroundColor, Color? collapsedIconColor, Color? expandedBackgroundColor, Color? highlightedBackgroundColor, Color? highlightedIconColor, Color? normalIconColor, Color? collapseIconColor, Color? brushPanelBackgroundColor, Color? brushPanelActiveColor, Color? brushPanelTextColor, Color? footerContainerBackgroundColor, Color? footerIconColor, Color? footerPageBackgroundColor, Color? footerPageTextColor, Color? footerBoardListBackgroundColor, Color? footerBoardListActiveBackgroundColor, Color? footerBoardListTextColor, Color? footerBoardListActiveTextColor, Color? footerDeleteIconColor})

Properties

brushPanelActiveColor Color?
画笔面板激活色
getter/setter pair
brushPanelBackgroundColor Color?
画笔面板背景色
getter/setter pair
brushPanelTextColor Color?
画笔面板文字颜色
getter/setter pair
collapsedBackgroundColor Color?
========== 白板工具栏样式配置 ========== 折叠状态背景色
getter/setter pair
collapsedIconColor Color?
折叠状态图标颜色
getter/setter pair
collapseIconColor Color?
折叠按钮图标颜色
getter/setter pair
enableBoardList bool?
是否启用白板列表,当有白板权限时
getter/setter pair
enableCreateBoard bool?
是否启用创建白板,当有白板权限时
getter/setter pair
enableSwitchPage bool?
是否PPT课件可翻页,当有白板权限时
getter/setter pair
expandedBackgroundColor Color?
展开状态背景色
getter/setter pair
footerBoardListActiveBackgroundColor Color?
底部工具栏白板列表激活项背景色
getter/setter pair
footerBoardListActiveTextColor Color?
底部工具栏白板列表激活项文字颜色
getter/setter pair
footerBoardListBackgroundColor Color?
底部工具栏白板列表背景色
getter/setter pair
footerBoardListTextColor Color?
底部工具栏白板列表文字颜色
getter/setter pair
footerContainerBackgroundColor Color?
========== 白板底部工具栏样式配置 ========== 底部工具栏容器背景色
getter/setter pair
footerDeleteIconColor Color?
底部工具栏删除按钮颜色
getter/setter pair
footerIconColor Color?
底部工具栏图标颜色
getter/setter pair
footerPageBackgroundColor Color?
底部工具栏页码背景色
getter/setter pair
footerPageTextColor Color?
底部工具栏页码文字颜色
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
highlightedBackgroundColor Color?
高亮工具项背景色
getter/setter pair
highlightedIconColor Color?
高亮工具项图标颜色
getter/setter pair
normalIconColor Color?
普通工具项图标颜色
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) WhiteboardComponentConfig
override