Member class abstract

Annotations
  • @freezed

Constructors

Member({@Default.new(0) int camera, @Default.new(0) int mic, @Default.new(0) int silence, @Default.new(0) int handUp, @Default.new(0) int board, @Default.new(0) int platform, @Default.new(0) int screen, @Default.new(0) int stage, @Default.new(0) int mute, @Default.new(0) int device, @Default.new(0) int role, @Default.new(0) int trophy, @Default.new("") String avatar, @Default.new("") String location, @Default.new("") String coordinates, @JsonKey.new(name: "user_id") @Default.new("") String userId, @JsonKey.new(name: "user_name") @Default.new("") String userName, @JsonKey.new(name: 'join_type') @Default.new(0) int joinType, @JsonKey.new(name: 'present_time') @Default.new(0) int presentTime, @JsonKey.new(name: 'im_count') @Default.new(0) int imCount, @JsonKey.new(name: 'answer_questions') @Default.new(0) int answerQuestions, @JsonKey.new(name: 'mic_state') @Default.new(0) int micState, @JsonKey.new(name: 'camera_state') @Default.new(0) int cameraState, @JsonKey.new(name: 'screen_state') @Default.new(0) int screenState, @JsonKey.new(name: 'classroom_code') @Default.new("") String classroomCode, @JsonKey.new(name: 'group_live_code') @Default.new("") String groupLiveCode, @JsonKey.new(name: 'hand_up_times') @Default.new(0) int handUpTimes, @JsonKey.new(name: 'ip_address') @Default.new("") String ipAddress, @JsonKey.new(name: 'visible_state') @Default.new(0) int visibleState, @JsonKey.new(name: 'last_enter_time') @Default.new(0) int lastEnterTime, @JsonKey.new(name: 'join_classroom_time') @Default.new(0) int joinClassroomTime, @JsonKey.new(name: 'hand_up_timestamp') @Default.new(0) int handUpTimestamp, @JsonKey.new(name: 'hand_down_timestamp') @Default.new(0) int handDownTimestamp, @JsonKey.new(name: 'first_join_timestamp') @Default.new(0) int firstJoinTimestamp, @JsonKey.new(name: 'last_quit_timestamp') @Default.new(0) int lastQuitTimestamp, @JsonKey.new(name: 'current_state') @Default.new(0) int currentState})
factory
Member.fromJson(Map<String, dynamic> json)
factory

Properties

answerQuestions int
no setterinherited
avatar String
no setterinherited
board int
no setterinherited
camera int
no setterinherited
cameraState int
no setterinherited
classroomCode String
no setterinherited
coordinates String
no setterinherited
copyWith → $MemberCopyWith<Member>
Create a copy of Member with the given fields replaced by the non-null parameter values.
no setterinherited
currentState int
no setterinherited
device int
no setterinherited
firstJoinTimestamp int
no setterinherited
groupLiveCode String
no setterinherited
handDownTimestamp int
no setterinherited
handUp int
no setterinherited
handUpTimes int
no setterinherited
handUpTimestamp int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
imCount int
no setterinherited
ipAddress String
no setterinherited
joinClassroomTime int
no setterinherited
joinType int
no setterinherited
lastEnterTime int
no setterinherited
lastQuitTimestamp int
no setterinherited
location String
no setterinherited
mic int
no setterinherited
micState int
no setterinherited
mute int
no setterinherited
platform int
no setterinherited
presentTime int
no setterinherited
role int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screen int
no setterinherited
screenState int
no setterinherited
silence int
no setterinherited
stage int
no setterinherited
trophy int
no setterinherited
userId String
no setterinherited
userName String
no setterinherited
visibleState int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this Member to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited