TCICNameConfig class abstract

Annotations
  • @freezed

Constructors

TCICNameConfig({required NameConfigInfo zh, required NameConfigInfo en, NameConfigInfo? ja, NameConfigInfo? ko, NameConfigInfo? zhTw})
factory
TCICNameConfig.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $TCICNameConfigCopyWith<TCICNameConfig>
Create a copy of TCICNameConfig with the given fields replaced by the non-null parameter values.
no setterinherited
en NameConfigInfo
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
ja NameConfigInfo?
no setterinherited
ko NameConfigInfo?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zh NameConfigInfo
no setterinherited
zhTw NameConfigInfo?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this TCICNameConfig to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited