QualitySet class

Inheritance

Constructors

QualitySet({required int camBitrate, required int camResolution, required int screenFps, required int screenResolution})

Properties

camBitrate ↔ int
getter/setter pair
camResolution ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenFps ↔ int
getter/setter pair
screenResolution ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → QualitySet
override