CustomContent class

Constructors

CustomContent({String scene = '', String logoUrl = '', String homeUrl = '', String jsUrl = '', String cssUrl = ''})

Properties

cssUrl String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
homeUrl String
getter/setter pair
jsUrl String
getter/setter pair
logoUrl String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scene String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) CustomContent