TaskInfo class abstract

Inheritance
Annotations
  • @freezed

Constructors

TaskInfo({@JsonKey.new(name: 'seq') @Default.new(0) int seq, @JsonKey.new(name: 'task_id') @Default.new('') String taskId, @JsonKey.new(name: 'status') @Default.new(0) int status, @JsonKey.new(name: 'content') @Default.new('') String content, @JsonKey.new(name: 'create_time') @Default.new(0) int createTime, @JsonKey.new(name: 'update_time') @Default.new(0) int updateTime, @JsonKey.new(name: 'expire_time') @Default.new(0) int expireTime, @JsonKey.new(name: 'binding_user') @Default.new('') String bindingUser, @Default.new(false) bool isSelfUpdate})
factory
TaskInfo.fromJson(Map<String, dynamic> json)
factory

Properties

bindingUser → String
绑定用户
no setterinherited
content → String
任务内容
no setterinherited
copyWith → $TaskInfoCopyWith<TaskInfo>
Create a copy of TaskInfo with the given fields replaced by the non-null parameter values.
no setterinherited
createTime → int
任务创建时间
no setterinherited
expireTime → int
任务过期时间
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isSelfUpdate → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seq → int
任务序号
no setterinherited
status → int
任务状态
no setterinherited
taskId → String
任务 ID
no setterinherited
updateTime → int
任务更新时间
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this TaskInfo to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited