SetTranslateTextBody class

Inheritance

Constructors

SetTranslateTextBody({required String classId, required TranslateStateEnum state, required TranslateLangEnum lang})

Properties

classId → String
final
hashCode → int
The hash code for this object.
no setterinherited
lang → TranslateLangEnum
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → TranslateStateEnum
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → SetTranslateTextBody
override