UpdateClassTaskBody class

Inheritance

Constructors

UpdateClassTaskBody({required String classId, required String taskId, required String content, required int duration, required bool createOnly, required bool enableCallback, required String bindingUser})

Properties

bindingUser → String
final
classId → String
final
content → String
final
createOnly → bool
final
duration → int
final
enableCallback → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → UpdateClassTaskBody
override