TCICStartClassRepModel class

Inheritance

Constructors

TCICStartClassRepModel({required int errorCode, required String errorMsg, required String requestId})

Properties

errorCode → int
final
errorMsg → String
final
hashCode → int
The hash code for this object.
no setterinherited
requestId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → TCICStartClassRepModel
override