ClassSwitchNativeBridge class abstract
把切换状态变化转发给 Native 层的桥接接口。
由 tcic_client_moudle 使用 Apis 静态方法实现并通过
ClassSwitcher.bindNativeBridge 注入。所有方法在 status listener
内同步调用,实现侧的具体上行(MethodChannel.invokeMethod)应使用
fire-and-forget 语义,避免阻塞状态机。
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyFailed(
{required String currentClassId, String? targetClassId, required String reason}) → void - 切换失败(任意 → failed)。
-
notifySucceeded(
{required String newClassId}) → void - 切换成功(非 idle 且非 failed → idle)。
-
notifySwitching(
{required String currentClassId, required String targetClassId}) → void - 切换即将开始(idle → preparing)。
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited