ClassSwitchStatus class
ClassSwitcher 的快照值对象。所有字段不可变。
- currentClassId / targetClassId 为空串
''表示未设置。 - errorCode / errorMessage 仅在失败/重试态下有值,其它态应为 null。
Constructors
- ClassSwitchStatus({required SwitchState state, String currentClassId = '', String targetClassId = '', int retryCount = 0, int? errorCode, String? errorMessage})
-
const
Properties
- currentClassId → String
-
final
- errorCode → int?
-
final
- errorMessage → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- retryCount → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → SwitchState
-
final
- targetClassId → String
-
final
Methods
-
copyWith(
{SwitchState? state, String? currentClassId, String? targetClassId, int? retryCount, int? errorCode, String? errorMessage, bool clearError = false}) → ClassSwitchStatus - 返回一个修改了部分字段的新实例。
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- idleDefault → const ClassSwitchStatus