TaskController class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfTrophyCount ↔ int
-
getter/setter pair
Methods
-
clear(
) → dynamic -
diffTrophyContent(
String newContent) → List< Map< String, dynamic> > - 对比 trophy task 新旧数据,返回变化项(count 增加或新增的项) 首次调用仅初始化快照,返回空列表(不触发动画)
-
getLatestTaskSeq(
) → dynamic -
getTaskByTaskId(
String taskId) → List< TaskInfo> -
getTasks(
int seq) → Future< GetTaskResult?> -
initTasks(
{required int lastTaskSeq, required List< TaskInfo> tasks}) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
processTask(
TaskInfo task) → dynamic -
stopTask(
String taskId) → dynamic -
toString(
) → String -
A string representation of this object.
inherited
-
updateTask(
UpdateTaskParams param) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited