HeartbeatRetryPolicy class
Constructors
- HeartbeatRetryPolicy({required Duration initialDelay, required int fastRetryMaxCount, required Duration slowRetryInterval})
-
const
Properties
- fastRetryMaxCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialDelay → Duration
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slowRetryInterval → Duration
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
retryDelayForFailure(
int failureCount) → Duration -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited