PlayBackComponent class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- PlayBackComponent
Constructors
- PlayBackComponent({Key? key, required PlaybackConfig config, required TCICController controller, VoidCallback? onClose, VoidCallback? onPlaybackClosedNotify, void onPlaybackError(String error)?, PlaybackEventNotifier? onPlaybackEvent})
-
const
Properties
- config → PlaybackConfig
-
final
- controller → TCICController
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onClose → VoidCallback?
-
由外部注入的关闭回调(如 Native 打开的回放页),点击返回时优先调用,避免单路由下 Navigator.pop 导致白屏
final
- onPlaybackClosedNotify → VoidCallback?
-
页面 dispose 时通知 Native 关闭(仅发回调,不 setState),与 onClose 配合使用
final
- onPlaybackError → void Function(String error)?
-
回放错误时通知 Native
final
- onPlaybackEvent → PlaybackEventNotifier?
-
回放播放事件时通知 Native(play/pause/seek/timeupdate/ratechange/ended 等)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< PlayBackComponent> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited