UnrealBgData class
Constructors
-
UnrealBgData({List<
TCICVirtualBackgroundImage> ? customImages})
Properties
-
bgData
→ Map<
int, UnrealBgItem> -
no setter
-
customImages
→ List<
TCICVirtualBackgroundImage> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
findIndexByKey(
String key) → int? -
getItemByIndex(
int index) → UnrealBgItem? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
buildKeyFromImagePath(
String imagePath) → String -
sanitizeCustomImages(
List< TCICVirtualBackgroundImage> images) → List<TCICVirtualBackgroundImage>
Constants
- blurKey → const String
- classroomKey → const String
- libraryKey → const String
- noneKey → const String
- readingRoomKey → const String
- studyRoomKey → const String