DevicePlatform class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
addOrientationListener(
void listener(Orientation)) → void -
getDeviceOrientation(
) → Future< Orientation> -
isLandscape(
) → bool -
isPortrait(
) → bool -
notifyPlayBackPageClosed(
) → Future< void> - 通知 iOS/Android 关闭当前打开的原生回放页面(Flutter 回放页关闭时调用)
-
removeOrientationListener(
OrientationObserver observer) → void -
setAllOrientations(
) → Future< void> -
setLandscape(
) → Future< void> -
setLandscapeNative(
) → Future< void> -
setPortrait(
) → Future< void> -
setPortraitNative(
) → Future< void> -
setPreferredOrientations(
List< DeviceOrientation> orientations) → Future<void>