TCICFontManager class
TCIC字体管理器
Constructors
- TCICFontManager()
-
factory
Properties
- currentFontConfig → TCICFontConfig?
-
获取当前字体配置
no setter
- currentFontFamily → String?
-
获取当前字体族名
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
loadedFonts
→ Set<
String> -
获取已加载的字体列表
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
applyFontToStyle(
TextStyle style) → TextStyle - 应用字体到文本样式
-
applyFontToTheme(
ThemeData theme) → ThemeData - 应用字体到主题
-
clearFontCache(
) → Future< void> - 清除字体缓存
-
dispose(
) → void - 释放字体资源
-
initialize(
) → Future< void> - 初始化字体管理器
-
isFontLoaded(
String fontFamily) → bool - 检查字体是否已加载
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setFontConfig(
TCICFontConfig config) → Future< bool> - 设置字体配置
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited