TCICReport class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- batchSize ↔ int
-
getter/setter pair
- deviceInfoPlugin → DeviceInfoPlugin
-
final
- minReportTimerInterval ↔ int
-
getter/setter pair
-
moduleWhitelist
↔ List<
String> -
模块级白名单:命中的 actionModule 下所有日志均上报
getter/setter pair
- reportConfig ↔ ReportConfigModel?
-
getter/setter pair
- reportTimerInterval ↔ int
-
getter/setter pair
-
whitelist
↔ List<
String> -
日志上报白名单(按 actionName 匹配)
getter/setter pair
Static Methods
-
clearPlaybackContext(
) → void -
ensureReady(
) → Future< void> - 确保 init + startReport 均已执行(回放页等独立入口调用)。
-
getReportConfig(
) → Future< ReportConfigModel?> -
init(
) → Future< void> -
logCallback(
String? logId, String? logContent, int logLevel, String? logTopicId) → void -
mainEventChangeListener(
MainEvent event) → void -
report(
) → Future< void> -
setPlaybackContext(
{required String userId, required String classId}) → void -
startReport(
) → Future< void> -
stopAndFlush(
) → Future< void> -
stopReport(
) → void -
updateCache(
TCICLogParam logParam) → dynamic